<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="134"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="135"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="137"/>
        <source>Lightweight file manager</source>
        <translation>Administrador de archivos liviano</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="138"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="142"/>
        <source>Authors</source>
        <translation>Autores</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="139"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translatorcomment>Programado por:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="160"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="143"/>
        <source>PCMan File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>Administrador de archivos PCManFM

Copyright (C) 2009-2014 洪 任 諭 (Hong Jen Yee)

Este programa es software libre; puede redistribuirlo y / o
modificarlo bajo los términos de la Licencia Pública General GNU
publicada por la Fundación para el Software Libre; ya sea la versión 2
de la Licencia, o (a su elección) cualquier versión posterior.

Este programa se distribuye con la esperanza de que sea útil,
pero SIN NINGUNA GARANTÍA; ni siquiera la garantía implícita de
COMERCIALIZACIÓN o IDONEIDAD PARA UN PROPÓSITO PARTICULAR. Vea la
Licencia Pública General GNU para más detalles.

Debería haber recibido una copia de la Licencia Pública General GNU
junto con este programa; si no, escriba a la Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="110"/>
        <source>Removable medium is inserted</source>
        <translation>Disco removible insertado</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="112"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;Disco removible insertado&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="113"/>
        <source>Type of medium:</source>
        <translation>Tipo de disco:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="114"/>
        <source>Detecting...</source>
        <translation>Detectando...</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="115"/>
        <source>Please select the action you want to perform:</source>
        <translation>Seleccione la acción que desea ejecutar:</translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="75"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="76"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="77"/>
        <source>Desktop folder:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="79"/>
        <source>Image file</source>
        <translation type="unfinished">Archivo de imagen</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="84"/>
        <source>Folder path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="85"/>
        <source>&amp;Browse</source>
        <translation type="unfinished">E&amp;xaminar</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="254"/>
        <source>Desktop Preferences</source>
        <translation>Preferencias de Escritorio</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="275"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="255"/>
        <source>Background</source>
        <translation>Fondo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="256"/>
        <source>Wallpaper mode:</source>
        <translation>Modo de papel tapiz:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="257"/>
        <source>Wallpaper image file:</source>
        <translation>Imagen de papel tapiz:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="259"/>
        <source>Select background color:</source>
        <translation>Seleccione color de fondo:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="261"/>
        <source>Image file</source>
        <translation>Archivo de imagen</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="266"/>
        <source>Image file path</source>
        <translation>Ruta de archivo de imagen</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="267"/>
        <source>&amp;Browse</source>
        <translation>E&amp;xaminar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="268"/>
        <source>Label Text</source>
        <translation>Texto de etiquetas</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="271"/>
        <source>Select  text color:</source>
        <translation>Seleccione color de texto:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="272"/>
        <source>Select shadow color:</source>
        <translation>Seleccione color de sombra:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="273"/>
        <source>Select font:</source>
        <translation>Seleccione el tipo de letra:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="276"/>
        <source>Window Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="278"/>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="277"/>
        <source>Show menus provided by window managers when desktop is clicked</source>
        <translation>Mostrar menús de los administradores de ventanas cuando se hace click sobre el escritorio</translation>
    </message>
</context>
<context>
    <name>FindFilesDialog</name>
    <message>
        <source>Find Files</source>
        <translation type="vanished">Buscar archivos</translation>
    </message>
    <message>
        <source>Name/Location</source>
        <translation type="vanished">Nombre/Posición</translation>
    </message>
    <message>
        <source>File name patterns</source>
        <translation type="vanished">Patrones de nombre de archivos</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation type="vanished">Patrón:</translation>
    </message>
    <message>
        <source>Case insensitive</source>
        <translation type="vanished">No coincidir mayúsculas</translation>
    </message>
    <message>
        <source>Use regular expression</source>
        <translation type="vanished">Usar expresión regular</translation>
    </message>
    <message>
        <source>Places to search</source>
        <translation type="vanished">Lugares donde buscar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="vanished">Agregar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Eliminar</translation>
    </message>
    <message>
        <source>Search in sub directories</source>
        <translation type="vanished">Buscar en sub directorios</translation>
    </message>
    <message>
        <source>Search hidden files</source>
        <translation type="vanished">Buscar archivos ocultos</translation>
    </message>
    <message>
        <source>File Type</source>
        <translation type="vanished">Tipo de Archivo</translation>
    </message>
    <message>
        <source>Only search for files of following types:</source>
        <translation type="vanished">Solo buscar archivos de los siguientes tipos:</translation>
    </message>
    <message>
        <source>Text files</source>
        <translation type="vanished">Archivos de texto</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation type="vanished">Archivos de imágenes</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation type="vanished">Archivos de audio</translation>
    </message>
    <message>
        <source>Video files</source>
        <translation type="vanished">Archivos de video</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="vanished">Documentos</translation>
    </message>
    <message>
        <source>Content</source>
        <translation type="vanished">Contenido</translation>
    </message>
    <message>
        <source>File contains</source>
        <translation type="vanished">Contenidos del archivo</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation type="vanished">Propiedades</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation type="vanished">Tamaño del Archivo</translation>
    </message>
    <message>
        <source>Bigger than:</source>
        <translation type="vanished">Mayor a:</translation>
    </message>
    <message>
        <source>Smaller than:</source>
        <translation type="vanished">Menor a:</translation>
    </message>
    <message>
        <source>Last Modified Time</source>
        <translation type="vanished">Fecha de Modificación</translation>
    </message>
    <message>
        <source>Earlier than:</source>
        <translation type="vanished">Antes de:</translation>
    </message>
    <message>
        <source>Later than:</source>
        <translation type="vanished">Después de:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="557"/>
        <source>File Manager</source>
        <translation>Administrador de archivos</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="638"/>
        <source>Ctrl+Shift+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="640"/>
        <source>Ctrl+Alt+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="641"/>
        <source>&amp;Find Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="642"/>
        <source>F3</source>
        <translation type="unfinished">F3</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="643"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="644"/>
        <source>Filter by string...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="645"/>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="646"/>
        <source>C&amp;reate New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="647"/>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="648"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="649"/>
        <source>&amp;Sorting</source>
        <translation>&amp;Ordenar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="650"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="651"/>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Marcadores</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="652"/>
        <source>&amp;Go</source>
        <translation>&amp;Ir</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="653"/>
        <source>&amp;Tool</source>
        <translation>&amp;Herramientas</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="654"/>
        <source>Main Toolbar</source>
        <translation>Barra de Herramientas Principal</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="558"/>
        <source>Go &amp;Up</source>
        <translation>S&amp;ubir</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="560"/>
        <source>Go Up</source>
        <translation>Subir</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="562"/>
        <source>Alt+Up</source>
        <translation>Alt+Arriba</translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="vanished">Carpeta personal</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="563"/>
        <source>&amp;Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="564"/>
        <source>Alt+Home</source>
        <translation>Alt+Inicio</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="565"/>
        <source>&amp;Reload</source>
        <translation>&amp;Recargar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="566"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="567"/>
        <source>Go</source>
        <translation>Ir</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="568"/>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="569"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="570"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nueva ventana</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="572"/>
        <source>New Window</source>
        <translation>Nueva ventana</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="574"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="575"/>
        <source>Show &amp;Hidden</source>
        <translation>Mo&amp;strar ocultos</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="576"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="577"/>
        <source>&amp;Computer</source>
        <translation>&amp;Sistema</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="578"/>
        <source>&amp;Trash</source>
        <translation>&amp;Papelera</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="579"/>
        <source>&amp;Network</source>
        <translation>&amp;Red</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="580"/>
        <source>&amp;Desktop</source>
        <translation>&amp;Escritorio</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="581"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>&amp;Agregar a marcadores</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="582"/>
        <source>&amp;Applications</source>
        <translation>&amp;Aplicaciones</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="583"/>
        <source>Reload</source>
        <translation>Recargar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="584"/>
        <source>&amp;Icon View</source>
        <translation>V&amp;ista de Íconos</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="585"/>
        <source>&amp;Compact View</source>
        <translation>Vista &amp;Compacta</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="586"/>
        <source>&amp;Detailed List</source>
        <translation>Lista &amp;Detallada</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="587"/>
        <source>&amp;Thumbnail View</source>
        <translation>Vista de &amp;Miniaturas</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="588"/>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="589"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="590"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="591"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="592"/>
        <source>&amp;Paste</source>
        <translation>&amp;Pegar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="593"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="594"/>
        <source>Select &amp;All</source>
        <translation>Seleccion&amp;ar Todo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="595"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="596"/>
        <source>Pr&amp;eferences</source>
        <translation>Pr&amp;eferencias</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="597"/>
        <source>&amp;Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="598"/>
        <source>&amp;Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="599"/>
        <source>&amp;By File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="600"/>
        <source>By &amp;Modification Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="601"/>
        <source>By File &amp;Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="602"/>
        <source>By &amp;Owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="603"/>
        <source>&amp;Folder First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="629"/>
        <source>&amp;Case Sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="630"/>
        <source>By File &amp;Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="631"/>
        <source>&amp;Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="637"/>
        <source>&amp;Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="639"/>
        <source>&amp;Blank File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="vanished">Ascendente</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="vanished">Descendente</translation>
    </message>
    <message>
        <source>By File Name</source>
        <translation type="vanished">Por Nombre de Archivo</translation>
    </message>
    <message>
        <source>By Modification Time</source>
        <translation type="vanished">Por Fecha de Modificación</translation>
    </message>
    <message>
        <source>By File Type</source>
        <translation type="vanished">Por Tipo de Archivo</translation>
    </message>
    <message>
        <source>By Owner</source>
        <translation type="vanished">Por Dueño</translation>
    </message>
    <message>
        <source>Folder First</source>
        <translation type="vanished">Carpetas Primero</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="604"/>
        <source>New &amp;Tab</source>
        <translation>Nueva &amp;Pestaña</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="606"/>
        <source>New Tab</source>
        <translation>Nueva Pestaña</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="608"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="609"/>
        <source>Go &amp;Back</source>
        <translation>Re&amp;troceder</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="611"/>
        <source>Go Back</source>
        <translation>Retroceder</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="613"/>
        <source>Alt+Left</source>
        <translation>Alt+Izquierda</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="614"/>
        <source>Go &amp;Forward</source>
        <translation>A&amp;vanzar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="616"/>
        <source>Go Forward</source>
        <translation>Avanzar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="618"/>
        <source>Alt+Right</source>
        <translation>Alt+Derecha</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="619"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Invertir Selección</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="620"/>
        <source>&amp;Delete</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="621"/>
        <source>Del</source>
        <translation>Supr</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="622"/>
        <source>&amp;Rename</source>
        <translation>Cambia&amp;r Nombre</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="623"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="624"/>
        <source>C&amp;lose Tab</source>
        <translation>&amp;Cerrar Pestaña</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="625"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="626"/>
        <source>File &amp;Properties</source>
        <translation>Propiedades de &amp;Archivo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="627"/>
        <source>Alt+Return</source>
        <translation>Alt+Enter</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="628"/>
        <source>&amp;Folder Properties</source>
        <translation>&amp;Propiedades de &amp;Carpeta</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation type="vanished">Coincidir Mayúsculas</translation>
    </message>
    <message>
        <source>By File Size</source>
        <translation type="vanished">Por Tamaño de Archivo</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="vanished">Cerrar Ventana</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="632"/>
        <source>Edit Bookmarks</source>
        <translation>Editar Marcadores</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="633"/>
        <source>Open &amp;Terminal</source>
        <translation>Abrir &amp;terminal</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="634"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="635"/>
        <source>Open as &amp;Root</source>
        <translation>Abrir como &amp;root</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="636"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>&amp;Editar Marcadores</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="162"/>
        <source>Name of configuration profile</source>
        <translation>Nombre del perfil ce configuración</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="162"/>
        <source>PROFILE</source>
        <translation>PERFIL</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="165"/>
        <source>Run PCManFM as a daemon</source>
        <translation>Ejecutar PCManFM como un servicio</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="168"/>
        <source>Quit PCManFM</source>
        <translation>Cerrar PCManFM</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="171"/>
        <source>Launch desktop manager</source>
        <translation>Abrir administrador de escritorio</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="174"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>Cerrar administrador de escritorio si está en ejecución</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="177"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>Abrir diálogo de preferencias de escritorio en la página especificada</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="177"/>
        <location filename="../application.cpp" line="193"/>
        <source>NAME</source>
        <translation>NOMBRE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="180"/>
        <source>Open new window</source>
        <translation>Abrir nueva ventana</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="183"/>
        <source>Open Find Files utility</source>
        <translation>Abrir búsqueda de archivos</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>Configurar papel tapiz desde un archivo</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>FILE</source>
        <translation>ARCHIVO</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>Set mode of desktop wallpaper. MODE=(color|stretch|fit|center|tile)</source>
        <translation>Definir modo de papel tapiz. MODO =(color|stretch|fit|center|tile)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>MODE</source>
        <translation>MODO</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="193"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>Abrir diálogo de preferencias en la página especificada</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>Files or directories to open</source>
        <translation>Archivos o directorios a abrir</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[Archivo 1, Archivo 2,...]</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="500"/>
        <location filename="../application.cpp" line="507"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="507"/>
        <source>Terminal emulator is not set.</source>
        <translation>El emulador de terminal no está configurado.</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="43"/>
        <source>Open in file manager</source>
        <translation>Abrir en administrador de archivos</translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="133"/>
        <source>Removable Disk</source>
        <translation>Disco Removible</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="50"/>
        <source>Fill with background color only</source>
        <translation>Llenar solamente con el color de fondo</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="51"/>
        <source>Stretch to fill the entire screen</source>
        <translation>Estirar para llenar la pantalla</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="52"/>
        <source>Stretch to fit the screen</source>
        <translation>Estirar para ajustar a la pantalla</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="53"/>
        <source>Center on the screen</source>
        <translation>Centrar en la pantalla</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="54"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>Repetir la imagen hasta llenar la pantalla</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="157"/>
        <source>Image Files</source>
        <translation>Archivos de Imagen</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="366"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>&amp;Pegar en la posición actual</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="388"/>
        <source>Desktop Preferences</source>
        <translation>Preferencias de Escritorio</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Clear text (Ctrl+K)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="455"/>
        <source>Version: %1</source>
        <translation>Versión: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Mover a la Papelera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>&amp;Delete</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="969"/>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Switch user command is not set.</source>
        <translation>El comando para cambiar de usuario no está definido.</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="190"/>
        <source>Icon View</source>
        <translation>Vista de Íconos</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="191"/>
        <source>Compact Icon View</source>
        <translation>Vista Compacta de Íconos</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="192"/>
        <source>Thumbnail View</source>
        <translation>Vista de Miniaturas</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="193"/>
        <source>Detailed List View</source>
        <translation>Lista Detallada</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="248"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="261"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>Espacio libre: %1 (Total %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="276"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n elemento</numerusform>
            <numerusform>%n elementos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="278"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform> (%n oculto)</numerusform>
            <numerusform> (%n ocultos)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="426"/>
        <source>%1 item(s) selected</source>
        <translation>%1 elemento(s) seleccionado(s)</translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="103"/>
        <source>Open in New T&amp;ab</source>
        <translation>&amp;Abrir en Nueva Pestaña</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="107"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Abrir en Nueva &amp;Ventana</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="114"/>
        <source>Open in Termina&amp;l</source>
        <translation>Abrir en Termina&amp;l</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="706"/>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="715"/>
        <source>User Interface</source>
        <translation>Interfaz de Usuario</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="711"/>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="717"/>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="779"/>
        <source>Thumbnail</source>
        <translation>Miniaturas</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="719"/>
        <source>Volume</source>
        <translation>Volumen</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="721"/>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="742"/>
        <source>Icons</source>
        <translation>Íconos</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="744"/>
        <source>Size of big icons:</source>
        <translation>Tamaño de íconos grandes:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="745"/>
        <source>Size of small icons:</source>
        <translation>Tamaño de íconos pequeños:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="746"/>
        <source>Size of thumbnails:</source>
        <translation>Tamaño de miniaturas:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="747"/>
        <source>Size of side pane icons:</source>
        <translation>Tamaño de íconos del panel lateral:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="743"/>
        <source>Icon theme:</source>
        <translation>Tema de íconos:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="753"/>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="754"/>
        <source>Always show the tab bar</source>
        <translation>Mostrar siempre la barra de pestañas</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="755"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>Mostrar botones de cerrar en las pestañas</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="756"/>
        <source>Remember the size of the last closed window</source>
        <translation>Recordar el tamaño de la última ventana cerrada</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="757"/>
        <source>Default width of new windows:</source>
        <translation>Ancho para nuevas ventanas:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="758"/>
        <source>Default height of new windows:</source>
        <translation>Altura para nuevas ventanas:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="724"/>
        <source>Browsing</source>
        <translation>Navegación</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="725"/>
        <source>Open files with single click</source>
        <translation>Abrir archivos con un solo click</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="726"/>
        <source>Delay of auto-selection in single click mode (0 to disable)</source>
        <translation>Demora de selección automática en modo de un click (0 para deshabilitar)</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="727"/>
        <source>Default view mode:</source>
        <translation>Modo de visualización por defecto:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="728"/>
        <source> sec</source>
        <translation>seg</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="736"/>
        <source>File Operations</source>
        <translation>Operaciones de Archivos</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="737"/>
        <source>Confirm before deleting files</source>
        <translation>Confirmar antes de borrar</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="738"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>Mover archivos a la papelera en lugar de eliminarlos del disco.</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="783"/>
        <source>Show thumbnails of files</source>
        <translation>Mostrar miniaturas de archivos</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="782"/>
        <source>Only show thumbnails for local files</source>
        <translation>Solo mostrar miniaturas para archivos locales</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="713"/>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="729"/>
        <source>Bookmarks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="732"/>
        <source>Open in current tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="733"/>
        <source>Open in new tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="734"/>
        <source>Open in new window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="739"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="740"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="741"/>
        <source>Don&apos;t ask options on launch executable file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="748"/>
        <source>User interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="750"/>
        <source>Treat backup files as hidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="751"/>
        <source>Always show full file names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="752"/>
        <source>Show icons of hidden files shadowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="759"/>
        <source>Show in places</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="764"/>
        <source>Home</source>
        <translation type="unfinished">Carpeta personal</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="766"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="768"/>
        <source>Trash can</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="770"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="772"/>
        <source>Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="774"/>
        <source>Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="776"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="780"/>
        <source>Do not generate thumbnails for image files exceeding this size:</source>
        <translation>No generar miniaturas para archivos de imágenes mayores a:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="781"/>
        <source> KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="784"/>
        <source>Auto Mount</source>
        <translation>Montar Automáticamente</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="785"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>Montar discos removibles automáticamente al inicio</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="786"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>Montar discos removibles automáticamente cuando se insertan</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="787"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>Mostrar opciones disponibles para los discos removibles al insertarlos</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="788"/>
        <source>When removable medium unmounted:</source>
        <translation>Cuando se desconecta un disco removible:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="789"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="790"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="793"/>
        <source>Switch &amp;user command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="796"/>
        <source>Archiver in&amp;tegration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="797"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="798"/>
        <source>Show only user defined templates in menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="799"/>
        <source>Show only one template for each MIME type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="800"/>
        <source>Run default application after creation from template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close tab containing removable medium</source>
        <translation type="vanished">Cerrar la pestaña que contiene al disco removible</translation>
    </message>
    <message>
        <source>Change folder in the tab to home folder</source>
        <translation type="vanished">Cambiar el directorio en la pestaña a la carpeta personal</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="791"/>
        <source>Programs</source>
        <translation>Programas</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="792"/>
        <source>Terminal emulator:</source>
        <translation>Emulador de terminal:</translation>
    </message>
    <message>
        <source>Switch user command:</source>
        <translation type="vanished">Comando para cambiar de usuario:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="794"/>
        <source>Examples: &quot;xterm -e %s&quot; for terminal or &quot;gksu %s&quot; for switching user.
%s = the command line you want to execute with terminal or su.</source>
        <translation>Ejemplos: &quot;xterm -e %s&quot; para terminal o &quot;gksu %s&quot; para cambiar de usuario.
%s = la línea de comandos a ejecutar en la terminal o como otro usuario.</translation>
    </message>
    <message>
        <source>Archiver integration:</source>
        <translation type="vanished">Integración con programas de archivo:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="749"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>Usar prefijos decimales SI en lugar de prefijos binarios IEC</translation>
    </message>
</context>
</TS>
